package com.qmth.sop.business.templete.service.impl;

import com.alibaba.excel.EasyExcel;
import com.qmth.sop.business.bean.dto.UserArchivesImportDto;
import com.qmth.sop.business.entity.BasicAttachment;
import com.qmth.sop.business.entity.TBTask;
import com.qmth.sop.business.service.BasicAttachmentService;
import com.qmth.sop.business.templete.service.TaskLogicService;
import com.qmth.sop.business.util.ImportExportUtil;
import com.qmth.sop.business.util.excel.BasicExcelListener;
import com.qmth.sop.common.contant.SystemConstant;
import com.qmth.sop.common.enums.UploadFileEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.LinkedMultiValueMap;

import javax.annotation.Resource;
import java.io.File;
import java.io.InputStream;
import java.util.*;

/**
 * @Description: 任务处理逻辑impl
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/3/29
 */
@Service
public class TaskLogicServiceImpl implements TaskLogicService {
    private final static Logger log = LoggerFactory.getLogger(TaskLogicServiceImpl.class);

    @Resource
    ImportExportUtil importExportUtil;

    @Resource
    BasicAttachmentService basicAttachmentService;

    /**
     * 处理导入人员档案数据
     *
     * @param map 数据源
     * @return
     * @throws Exception
     */
    @Override
    @Transactional
    public Map<String, Object> executeImportUserArchivesLogic(Map<String, Object> map) throws Exception {
        InputStream inputStream = null;
        try {
            TBTask tbTask = (TBTask) map.get(SystemConstant.TASK);
            inputStream = importExportUtil.getUploadFileInputStream(tbTask);
            LinkedMultiValueMap<String, UserArchivesImportDto> userArchivesImportDtoLinkedMultiValueMap = new LinkedMultiValueMap<>();
            StringJoiner errorData = new StringJoiner("");
            EasyExcel.read(inputStream, UserArchivesImportDto.class, new BasicExcelListener<UserArchivesImportDto>() {

                @Override
                public void handle(LinkedMultiValueMap<String, UserArchivesImportDto> dataList, StringJoiner errorDataSj) {
                    userArchivesImportDtoLinkedMultiValueMap.addAll(dataList);
                    errorData.add(errorDataSj.toString());
                }
            }).headRowNumber(2).sheet(0).doRead();

            map.computeIfAbsent(SystemConstant.EXCEL_DATA, v -> userArchivesImportDtoLinkedMultiValueMap);
            map.computeIfAbsent(SystemConstant.EXCEL_DATA_ERROR, v -> errorData.toString());

            //处理数据逻辑
        } finally {
            if (Objects.nonNull(inputStream)) {
                inputStream.close();
            }
        }
        return map;
    }

    /**
     * 处理导出人员档案数据
     *
     * @param map 数据源
     * @return
     * @throws Exception
     */
    @Override
    @Transactional
    public Map<String, Object> executeExportUserArchivesLogic(Map<String, Object> map) throws Exception {
        File fileTemp = null;
        try {
            fileTemp = SystemConstant.getFileTempVar(SystemConstant.XLSX_PREFIX);
            //数据读取逻辑start
            List<UserArchivesImportDto> archivesImportDtoList = new ArrayList<>();
            archivesImportDtoList.add(new UserArchivesImportDto("1", "2", "123", "aaa", "bbb"));
            archivesImportDtoList.add(new UserArchivesImportDto("4", "5", "789", "ccc", "ddd"));
            //数据读取逻辑end
            EasyExcel.write(fileTemp, UserArchivesImportDto.class).sheet("人员档案导出").doWrite(archivesImportDtoList);

            BasicAttachment basicAttachment = basicAttachmentService.saveAttachment(fileTemp, UploadFileEnum.FILE);
            map.computeIfAbsent(SystemConstant.EXCEL_DATA, v -> archivesImportDtoList);
            map.computeIfAbsent(SystemConstant.EXCEL_ATTACHMENT, v -> basicAttachment);
        } finally {
            if (Objects.nonNull(fileTemp)) {
                fileTemp.delete();
            }
        }
        return map;
    }
}
